# Urls
API_URL = 'https://stockx.com/api'
ALGOLIA_URL = (
    "https://xw7sbct9v6-1.algolianet.com/1/indexes/products/query?x-algolia-agent=Algolia%20for%20vanilla"
    "%20JavaScript%203.32.1&x-algolia-application-id=XW7SBCT9V6&x-algolia-api-key"
    "=6b5e76b49705eb9f51a06d3c82f7acee "
)

# End points
GET_PRODUCT = f'{API_URL}/products'
SEARCH_PRODUCTS = f'{API_URL}/browse'
CHART_DATA = 'chart'
SOLD_DATA = 'activity'

# Limits
SOLD_DATA_LIMIT = 250

# States
SOLD_STATE = 480



from stockx_wrapper import settings as st
from stockx_wrapper.products.product import Product
from stockx_wrapper.requester import requester


class Products:

    @staticmethod
    def get_product_data(product_id, country='US', currency='USD'):
        """
        Get product data by product id.

        :param product_id: str
        :param country: str, optional
            Country for focusing market information.
        :param currency: str, optional
            Currency to get. Tested with 'USD' and 'EUR'.

        :return: Product
            Product info.
        """

        # Format url and get data
        url = f'{st.GET_PRODUCT}/{product_id}'
        params = {
            'includes': 'market',
            'currency': currency,
            'country': country
        }
        data = requester.get(url=url, params=params)
        _product = data.get('Product')

        if _product:
            return Product(product_data=_product)

        return None

    def search_products(self, product_name, country='US', currency='USD'):
        """
        Search by product name.

        :param product_name: str
        :param country: str, optional
            Country for focusing market information.
        :param currency: str, optional
            Currency to get. Tested with 'USD' and 'EUR'.

        :return: Product
            Product info. First hit.
        """

        # Replace spaces to hexadecimal
        product_name = product_name.replace(' ', '%20')

        # Format url and get data
        url = st.SEARCH_PRODUCTS
        params = {
            'page': '1',
            '_search': product_name,
            'dataType': 'product'
        }
        data = requester.get(url=url, params=params)
        products = data.get('Products')

        if products:
            # Return first hit
            product_data = data['Products'][0]
            _product = self.get_product_data(product_id=product_data['id'], country=country, currency=currency)
            return _product

        return None

    @staticmethod
    def search_products_new_api(product_name):
        """
        Uses new API from Algolia. NOT WORKING FOR NOW.

        :param product_name:

        :return: Product
            Product info. First hit.
        """
        # Replace spaces to hexadecimal
        product_name = product_name.replace(' ', '%20')

        body = {
            'params': f'query={product_name}&facets=*&filters='
        }

        data = requester.post(url=st.ALGOLIA_URL, body=body)
        products = data.get('Products')

        if products:
            # Return first hit
            return Product(product_data=data['Products'][0])

        return None



import pathlib
from setuptools import find_packages, setup

import versioneer

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name='stockx-wrapper-py',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description='Simple Stockx Api for python 3',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://github.com/EduardoHerreraM/stockx-wrapper-py',
    author='EduardoHerreraM',
    packages=find_packages(exclude=['tests']),
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6'
    ],
    install_requires=[
        'requests'
    ]
)


import json
import requests


class Requester:
    def __init__(self):

        self.headers = {
            'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64; rv:86.0) Gecko/20100101 Firefox/86.0',
            'sec-fetch-dest': 'none',
            'accept': '*/*',
            'sec-fetch-site': 'cross-site',
            'sec-fetch-mode': 'cors',
            'accept-language': 'en-US'
        }

    def get(self, url, params=None):
        """
        Perform a http get request.

        :param url: str
        :param params: dict, optional

        :return: dict
            Json format
        """
        response = requests.get(url, headers=self.headers, params=params)
        data = json.loads(response.content)
        return data

    def post(self, url, params=None, body=None):
        """
        Perform a http post request.

        :param url: str
        :param params: dict, optional
        :param body: dict, optional

        :return:
        """

        response = requests.post(url, headers=self.headers, params=params, json=body)
        data = json.loads(response.content)
        return data


requester = Requester()
